@@ -101,33 +101,36 @@ BLK_DEVICE_TEMPLATE = """
 {
     "blockdevices": [
         {"kname":"sda", "model":"TinyUSB Drive", "size":3116853504,
-        "rota":false, "type":"disk", "serial":123, "uuid":"F531-BDC3",
+        "rota":false, "type":"disk", "serial":"sda123", "uuid":"F531-BDC3",
         "partuuid":null},
         {"kname":"sdb", "model":"Fastable SD131 7", "size":10737418240,
-        "rota":false, "type":"disk",
+        "rota":false, "type":"disk", "serial":"sdb123",
         "uuid":"9a5e5cca-e03d-4cbd-9054-9e6ca9048222", "partuuid":null},
         {"kname":"sdc", "model":"NWD-BLP4-1600", "size":1765517033472,
-        "rota":false, "type":"disk", "uuid":null, "partuuid":null},
+        "rota":false, "type":"disk", "serial":"sdc123", "uuid":null,
+        "partuuid":null},
         {"kname":"sdd", "model":"NWD-BLP4-1600", "size":1765517033472,
-        "rota":false, "type":"disk", "uuid":null, "partuuid":null},
+        "rota":false, "type":"disk", "serial":"sdd123", "uuid":null,
+        "partuuid":null},
         {"kname":"loop0", "model":null, "size":109109248, "rota":true,
-        "type":"loop", "uuid":null, "partuuid": null},
+        "type":"loop", "serial":null, "uuid":null, "partuuid": null},
         {"kname":"zram0", "model":null, "size":0, "rota":false, "type":"disk",
-        "uuid":null, "partuuid":null},
+        "serial":null, "uuid":null, "partuuid":null},
         {"kname":"ram0", "model":null, "size":8388608, "rota":false,
-        "type":"disk", "uuid":null, "partuuid":null},
+        "type":"disk", "serial":null, "uuid":null, "partuuid":null},
         {"kname":"ram1", "model":null, "size":8388608, "rota":false,
-        "type":"disk", "uuid":null, "partuuid":null},
+        "type":"disk", "serial":null, "uuid":null, "partuuid":null},
         {"kname":"ram2", "model":null, "size":8388608, "rota":false,
-        "type":"disk", "uuid":null, "partuuid":null},
+        "type":"disk", "serial":null,  "uuid":null, "partuuid":null},
         {"kname":"ram3", "model":null, "size":8388608, "rota":false,
-        "type":"disk", "uuid":null, "partuuid":null},
+        "type":"disk", "serial":null, "uuid":null, "partuuid":null},
         {"kname":"fd1", "model":"magic", "size":4096, "rota":true,
-        "type":"disk", "uuid":null, "partuuid":null},
+        "type":"disk", "serial":null, "uuid":null, "partuuid":null},
         {"kname":"sdf", "model":"virtual floppy", "size":0, "rota":true,
-        "type":"disk", "uuid":null, "partuuid":null},
+        "type":"disk", "serial":null, "uuid":null, "partuuid":null},
         {"kname":"dm-0", "model":"NWD-BLP4-1600", "size":"1765517033472",
-        "rota":false, "type":"mpath", "uuid":null, "partuuid":null}
+        "rota":false, "type":"mpath", "serial":null, "uuid":null,
+        "partuuid":null}
     ]
 }
 """
@@ -137,9 +140,22 @@ BLK_DEVICE_TEMPLATE_SMALL = """
 {
   "blockdevices": [
     {"kname":"sda", "model":"TinyUSB Drive", "size":3116853504, "rota":false,
-    "type":"disk", "uuid":"F531-BDC", "partuuid":null},
+    "type":"disk", "serial":"123", "uuid":"F531-BDC", "partuuid":null},
     {"kname":"sdb", "model":"AlmostBigEnough Drive", "size":"4294967295",
-    "rota":false, "type":"disk", "uuid":null, "partuuid":null}
+    "rota":false, "type":"disk", "serial":"456", "uuid":null, "partuuid":null}
+  ]
+}
+"""
+
+
+# NOTE This is intentionally have serials removed
+BLK_INCOMPLETE_DEVICE_TEMPLATE_SMALL = """
+{
+  "blockdevices": [
+    {"kname":"sda", "model":"TinyUSB Drive", "size":3116853504, "rota":false,
+    "type":"disk", "serial":"", "uuid":"F531-BDC", "partuuid":null},
+    {"kname":"sdb", "model":"AlmostBigEnough Drive", "size":"4294967295",
+    "rota":false, "type":"disk", "serial":"", "uuid":null, "partuuid":null}
   ]
 }
 """
@@ -155,23 +171,23 @@ RAID_BLK_DEVICE_TEMPLATE = ("""
 {
     "blockdevices": [
       {"kname":"sda", "model":"DRIVE 0", "size":1765517033472, "rota":true,
-      "type":"disk", "uuid":null, "partuuid":null},
+      "type":"disk", "serial":"sda123", "uuid":null, "partuuid":null},
       {"kname":"sda1", "model":"DRIVE 0", "size":107373133824, "rota":true,
-      "type":"part", "uuid":null, "partuuid":null},
+      "type":"part", "serial":"sda1123", "uuid":null, "partuuid":null},
       {"kname":"sdb", "model":"DRIVE 1", "size":1765517033472, "rota":true,
-      "type":"disk", "uuid":null, "partuuid":null},
+      "type":"disk", "serial":"sdb123", "uuid":null, "partuuid":null},
       {"kname":"sdb", "model":"DRIVE 1", "size":1765517033472, "rota":true,
       "type":"disk", "uuid":null, "partuuid":null},
       {"kname":"sdb1", "model":"DRIVE 1", "size":107373133824, "rota":true,
-      "type":"part", "uuid":null, "partuuid":null},
+      "type":"part", "serial":"sdb1123", "uuid":null, "partuuid":null},
       {"kname":"md0p1", "model":"RAID", "size":107236818944, "rota":false,
-      "type":"md", "uuid":null, "partuuid":null},
+      "type":"md", "serial":null, "uuid":null, "partuuid":null},
       {"kname":"md0", "model":"RAID", "size":1765517033470, "rota":false,
-      "type":"raid1", "uuid":null, "partuuid":null},
+      "type":"raid1", "serial":null, "uuid":null, "partuuid":null},
       {"kname":"md0", "model":"RAID", "size":1765517033470, "rota":false,
-      "type":"raid1", "uuid":null, "partuuid":null},
+      "type":"raid1", "serial":null, "uuid":null, "partuuid":null},
       {"kname":"md1", "model":"RAID", "size":0, "rota":false, "type":"raid1",
-      "uuid":null, "partuuid":null}
+      "serial":null, "uuid":null, "partuuid":null}
     ]
 }
 """)
@@ -180,49 +196,52 @@ MULTIPATH_BLK_DEVICE_TEMPLATE = ("""
 {
     "blockdevices": [
       {"kname":"sda", "model":"INTEL_SSDSC2CT060A3", "size":"60022480896",
-      "rota":false, "type":"disk", "uuid":null, "partuuid":null},
+      "rota":false, "type":"disk", "serial":"sda123", "uuid":null,
+      "partuuid":null},
       {"kname":"sda2", "model":null, "size":"59162722304", "rota":false,
       "type":"part", "uuid":"f8b55d59-96c3-3982-b129-1b6b2ee8da86",
-      "partuuid":"c97c8aac-7796-4433-b1fc-9b5fac43edf3"},
+      "partuuid":"c97c8aac-7796-4433-b1fc-9b5fac43edf3", "serial":"sda2123"},
       {"kname":"sda3", "model":null, "size":"650002432", "rota":false,
       "type":"part", "uuid":"b3b03565-5f13-3c93-b2a6-6d90e25be926",
-      "partuuid":"6c85beff-b2bd-4a1c-91b7-8abb5256459d"},
+      "partuuid":"6c85beff-b2bd-4a1c-91b7-8abb5256459d", "serial":"sda3123"},
       {"kname":"sda1", "model":null, "size":"209715200", "rota":false,
       "type":"part", "uuid":"0a83355d-7500-3f5f-9abd-66f6fd03714c",
-      "partuuid":"eba28b26-b76a-402c-94dd-0b66a523a485"},
+      "partuuid":"eba28b26-b76a-402c-94dd-0b66a523a485", "serial":"sda1123"},
       {"kname":"dm-0", "model":null, "size":"60022480896", "rota":false,
-      "type":"mpath", "uuid":null, "partuuid":null},
+      "type":"mpath", "serial":null, "uuid":null, "partuuid":null},
       {"kname":"dm-4", "model":null, "size":"650002432", "rota":false,
       "type":"part", "uuid":"b3b03565-5f13-3c93-b2a6-6d90e25be926",
-      "partuuid":"6c85beff-b2bd-4a1c-91b7-8abb5256459d"},
+      "partuuid":"6c85beff-b2bd-4a1c-91b7-8abb5256459d", "serial":null},
       {"kname":"dm-2", "model":null, "size":"209715200", "rota":false,
       "type":"part", "uuid":"0a83355d-7500-3f5f-9abd-66f6fd03714c",
-      "partuuid":"eba28b26-b76a-402c-94dd-0b66a523a485"},
+      "partuuid":"eba28b26-b76a-402c-94dd-0b66a523a485", "serial":null},
       {"kname":"dm-3", "model":null, "size":"59162722304", "rota":false,
       "type":"part", "uuid":"f8b55d59-96c3-3982-b129-1b6b2ee8da86",
-      "partuuid":"c97c8aac-7796-4433-b1fc-9b5fac43edf3"},
+      "partuuid":"c97c8aac-7796-4433-b1fc-9b5fac43edf3", "serial":null},
       {"kname":"sdb", "model":"INTEL_SSDSC2CT060A3", "size":"60022480896",
-      "rota":false, "type":"disk", "uuid":null, "partuuid":null},
+      "rota":false, "type":"disk", "serial":"sdb123", "uuid":null,
+      "partuuid":null},
       {"kname":"sdb2", "model":null, "size":"59162722304",
-      "rota":false, "type":"part",
+      "rota":false, "type":"part", "serial":"sdb2123",
       "uuid":"f8b55d59-96c3-3982-b129-1b6b2ee8da86",
       "partuuid":"c97c8aac-7796-4433-b1fc-9b5fac43edf3"},
       {"kname":"sdb3", "model":null, "size":"650002432",
-      "rota":false, "type":"part",
+      "rota":false, "type":"part", "serial":"sdv3123",
       "uuid":"b3b03565-5f13-3c93-b2a6-6d90e25be926",
       "partuuid":"6c85beff-b2bd-4a1c-91b7-8abb5256459d"},
       {"kname":"sdb1", "model":null, "size":"209715200",
-      "rota":false, "type":"part",
+      "rota":false, "type":"part", "serial":"sdb1123",
       "uuid":"0a83355d-7500-3f5f-9abd-66f6fd03714c",
       "partuuid":"eba28b26-b76a-402c-94dd-0b66a523a485"},
       {"kname":"sdc", "model":"ST1000DM003-1CH162", "size":"1000204886016",
-      "rota":true, "type":"disk", "uuid":null, "partuuid":null},
+      "rota":true, "type":"disk", "serial":"sdc123", "uuid":null,
+      "partuuid":null},
       {"kname":"sdc1", "model":null, "size":"899999072256",
-      "rota":true, "type":"part",
+      "rota":true, "type":"part", "serial":"sdc1123",
       "uuid":"457f7d3c-9376-4997-89bd-d1a7c8b04060",
       "partuuid":"c9433d2e-3bbc-47b4-92bf-43c1d80f06e0"},
       {"kname":"dm-1", "model":null, "size":"1000204886016", "rota":false,
-      "type":"mpath", "uuid":null, "partuuid":null}
+      "type":"mpath", "serial":null, "uuid":null, "partuuid":null}
     ]
 }
 """)
@@ -231,9 +250,10 @@ PARTUUID_DEVICE_TEMPLATE = ("""
 {
     "blockdevices": [
       {"kname":"sda", "model":"DRIVE 0", "size":1765517033472, "rota":true,
-      "type":"disk", "uuid":null, "partuuid":null},
+      "type":"disk", "serial":"sda123", "uuid":null, "partuuid":null},
       {"kname":"sda1", "model":"DRIVE 0", "size":107373133824, "rota":true,
-      "type":"part", "uuid":"987654-3210", "partuuid":"1234-5678"}
+      "type":"part", "serial":"sda1123", "uuid":"987654-3210",
+      "partuuid":"1234-5678"}
     ]
 }
 """)
@@ -470,6 +490,34 @@ LSHW_JSON_OUTPUT_V2 = ("""
       "serial" : "1234",
       "slot" : "NULL",
       "children" : [
+        {
+          "id": "firmware",
+          "class": "memory",
+          "claimed": true,
+          "description": "BIOS",
+          "vendor": "BIOSVNDR",
+          "physid": "0",
+          "version": "1.2.3",
+          "date": "03/30/2023",
+          "units": "bytes",
+          "size": 65536,
+          "capacity": 16777216,
+          "capabilities": {
+            "isa": "ISA bus",
+            "pci": "PCI bus",
+            "pnp": "Plug-and-Play",
+            "upgrade": "BIOS EEPROM can be upgraded",
+            "shadowing": "BIOS shadowing",
+            "cdboot": "Booting from CD-ROM/DVD",
+            "bootselect": "Selectable boot path",
+            "edd": "Enhanced Disk Drive extensions",
+            "acpi": "ACPI",
+            "usb": "USB legacy emulation",
+            "biosbootspecification": "BIOS boot specification",
+            "netboot": "Function-key initiated network service boot",
+            "uefi": "UEFI specification is supported"
+          }
+        },
         {
           "id" : "memory:0",
           "class" : "memory",
@@ -613,6 +661,60 @@ LSHW_JSON_OUTPUT_V2 = ("""
           "id" : "memory:5",
           "class" : "memory",
           "physid" : "2"
+        },
+        {
+          "id" : "network:0",
+          "class" : "network",
+          "handle" : "PCI:0000:00:14.3",
+          "description" : "Wireless interface",
+          "product" : "ABCD",
+          "vendor" : "ABCD",
+          "physid" : "14.3",
+          "businfo" : "pci@0000:00:14.3",
+          "logicalname" : "wlp0s20f3",
+          "width" : 64,
+          "clock" : 33000000,
+          "capabilities" : {
+            "pm" : "Power Management",
+            "msi" : "Message Signalled Interrupts",
+            "pciexpress" : "PCI Express",
+            "msix" : "MSI-X",
+            "bus_master" : "bus mastering",
+            "cap_list" : "PCI capabilities listing",
+            "ethernet" : true,
+            "physical" : "Physical interface",
+            "wireless" : "Wireless-LAN"
+          }
+        },
+        {
+          "id" : "network:1",
+          "class" : "network",
+          "handle" : "PCI:0000:00:1f.6",
+          "description" : "Ethernet interface",
+          "product" : "DCBA",
+          "vendor" : "DCBA",
+          "physid" : "1f.6",
+          "businfo" : "pci@0000:00:1f.6",
+          "logicalname" : "eth0",
+          "units" : "bit/s",
+          "capacity" : 1000000000,
+          "width" : 32,
+          "clock" : 33000000,
+          "capabilities" : {
+            "pm" : "Power Management",
+            "msi" : "Message Signalled Interrupts",
+            "bus_master" : "bus mastering",
+            "cap_list" : "PCI capabilities listing",
+            "ethernet" : true,
+            "physical" : "Physical interface",
+            "tp" : "twisted pair",
+            "10bt" : "10Mbit/s",
+            "10bt-fd" : "10Mbit/s (full duplex)",
+            "100bt" : "100Mbit/s",
+            "100bt-fd" : "100Mbit/s (full duplex)",
+            "1000bt-fd" : "1Gbit/s (full duplex)",
+            "autonegotiation" : "Auto-negotiation"
+          }
         }
       ]
     }
@@ -1031,6 +1133,61 @@ Working Devices : 2
        1     259        3        1      active sync   /dev/nvme1n1p1
 """)
 
+MDADM_DETAIL_OUTPUT_VOLUME_NAME = ("""/dev/md0:
+           Version : 1.0
+     Creation Time : Fri Feb 15 12:37:44 2019
+        Raid Level : raid1
+        Array Size : 1048512 (1023.94 MiB 1073.68 MB)
+     Used Dev Size : 1048512 (1023.94 MiB 1073.68 MB)
+      Raid Devices : 2
+     Total Devices : 2
+       Persistence : Superblock is persistent
+
+       Update Time : Fri Feb 15 12:38:02 2019
+             State : clean
+    Active Devices : 2
+   Working Devices : 2
+    Failed Devices : 0
+     Spare Devices : 0
+
+Consistency Policy : resync
+
+              Name : abc.xyz.com:this_name  (local to host abc.xyz.com)
+              UUID : 83143055:2781ddf5:2c8f44c7:9b45d92e
+            Events : 17
+
+    Number   Major   Minor   RaidDevice State
+       0     253       64        0      active sync   /dev/vde1
+       1     253       80        1      active sync   /dev/vdf1
+""")
+
+MDADM_DETAIL_OUTPUT_VOLUME_NAME_INVALID = ("""/dev/md0:
+           Version : 1.0
+     Creation Time : Fri Feb 15 12:37:44 2019
+        Raid Level : raid1
+        Array Size : 1048512 (1023.94 MiB 1073.68 MB)
+     Used Dev Size : 1048512 (1023.94 MiB 1073.68 MB)
+      Raid Devices : 2
+     Total Devices : 2
+       Persistence : Superblock is persistent
+
+       Update Time : Fri Feb 15 12:38:02 2019
+             State : clean
+    Active Devices : 2
+   Working Devices : 2
+    Failed Devices : 0
+     Spare Devices : 0
+
+Consistency Policy : resync
+
+              UUID : 83143055:2781ddf5:2c8f44c7:9b45d92e
+            Events : 17
+
+    Number   Major   Minor   RaidDevice State
+       0     253       64        0      active sync   /dev/vde1
+       1     253       80        1      active sync   /dev/vdf1
+""")
+
 MDADM_DETAIL_OUTPUT_BROKEN_RAID0 = ("""/dev/md126:
            Version : 1.2
         Raid Level : raid0
@@ -1049,6 +1206,34 @@ MDADM_DETAIL_OUTPUT_BROKEN_RAID0 = ("""/dev/md126:
        -       8        2        -        /dev/sda2
 """)
 
+# NOTE(TheJulia): The name and events field, in some cases can
+# match the regex causing parsing of the text to fail.
+MDADM_DETAIL_POISONED = ("""/dev/md0:
+        Version : 1.2
+  Creation Time : Wed Aug 17 16:09:19 2022
+     Raid Level : raid1
+     Array Size : 4673536 (4.46 GiB 4.79 GB)
+  Used Dev Size : 4673536 (4.46 GiB 4.79 GB)
+   Raid Devices : 2
+  Total Devices : 2
+    Persistence : Superblock is persistent
+
+    Update Time : Wed Aug 17 16:10:03 2022
+          State : clean
+ Active Devices : 2
+Working Devices : 2
+ Failed Devices : 0
+  Spare Devices : 0
+
+           Name : box:/dev/md0  (local to host box)
+           UUID : e50fb152:aa80db1d:3c901b03:dd280e35
+         Events : 21/dev/md/dev/md
+
+    Number   Major   Minor   RaidDevice State
+       0     251        1        0      active sync   /dev/vda1
+       1     251       17        1      active sync   /dev/vdb1
+""")
+
 MDADM_EXAMINE_OUTPUT_MEMBER = ("""/dev/sda1:
           Magic : a92b4efc
         Version : 1.2
@@ -1579,8 +1764,38 @@ MULTIPATH_VALID_PATH = '%s is a valid multipath device path'
 MULTIPATH_INVALID_PATH = '%s is not a valid multipath device path'
 
 MULTIPATH_LINKS_DM = (
-    'SUPER_FRIENDLY_NAME %s ATA,INTEL SSDSC2CT06\n'
+    'SUPER_FRIENDLY_ NAME (12345) %s ATA, INTEL SSDSC2CT06\n'
     'size=56G features=\'1 retain_attached_hw_handler\' hwhandler=\'0\' wp=rw\n'  # noqa
     ' `-+- policy=\'service-time 0\' prio=1 status=active\n'
     '  `- 0:0:0:0 device s  8:0  active ready running\n'
 )
+
+LSBLK_OUPUT = ("""
+NAME="sda" TYPE="disk" FSTYPE=""
+NAME="sdb" TYPE="disk" FSTYPE=""
+""")
+
+LSBLK_OUPUT_ESP_RAID = ("""
+NAME="sda" TYPE="disk" FSTYPE=""
+NAME="sda1" TYPE="part" FSTYPE="linux_raid_member"
+NAME="md127" TYPE="raid1" FSTYPE=""
+NAME="md127p1" TYPE="md" FSTYPE="xfs"
+NAME="md127p2" TYPE="md" FSTYPE="iso9660"
+NAME="md127p14" TYPE="md" FSTYPE=""
+NAME="md127p15" TYPE="md" FSTYPE=""
+NAME="sda2" TYPE="part" FSTYPE="linux_raid_member"
+NAME="md126" TYPE="raid0" FSTYPE=""
+NAME="sda3" TYPE="part" FSTYPE="linux_raid_member"
+NAME="md125" TYPE="raid1" FSTYPE="vfat"
+NAME="sdb" TYPE="disk" FSTYPE=""
+NAME="sdb1" TYPE="part" FSTYPE="linux_raid_member"
+NAME="md127" TYPE="raid1" FSTYPE=""
+NAME="md127p1" TYPE="md" FSTYPE="xfs"
+NAME="md127p2" TYPE="md" FSTYPE="iso9660"
+NAME="md127p14" TYPE="md" FSTYPE=""
+NAME="md127p15" TYPE="md" FSTYPE=""
+NAME="sdb2" TYPE="part" FSTYPE="linux_raid_member"
+NAME="md126" TYPE="raid0" FSTYPE=""
+NAME="sdb3" TYPE="part" FSTYPE="linux_raid_member"
+NAME="md125" TYPE="raid1" FSTYPE="vfat"
+""")
